# MyCache.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
#  Copyright (c) 2004-2008 Canonical
#
#  Author: Michael Vogt <mvo@debian.org>
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License as
#  published by the Free Software Foundation; either version 2 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#  USA

import gi
gi.require_version('OSTree', '1.0')
from gi.repository import OSTree
import logging

LOCAL_SUMMARY_DATA = "/var/ostree-summary"

class MyCache():
    def __init__(self):
        # sysroot 
        self.sysroot = OSTree.Sysroot.new_default()
        self.sysroot.set_mount_namespace_in_use()
        self.sysroot.initialize()
        self.sysroot.load()

        self.deployment = self.sysroot.get_booted_deployment()

        self.cur_checksum = self.deployment.get_csum()

        self.osname = self.deployment.get_osname()

        oringin_f = self.deployment.get_origin()
        refspec = oringin_f.get_string("origin","refspec")
        ret,self.origin_remote,self.origin_ref = OSTree.parse_refspec(refspec)

        self.available_checksum = self.cur_checksum
        self.available_refs = self.origin_ref

    def is_upgradable(self):
        return self.available_checksum != self.deployment.get_osname()
    
    def _initDepCache(self):
        self._depcache.read_pinfile()
        self._depcache.init()

    def clear(self):
        self._initDepCache()

    def list_refs(self):
        repo = self.sysroot.repo()

        ret,all_refs = repo.list_refs(None,None)

        refs = list(all_refs.keys())
        
        return refs
    
    def rollback_deployment(self):
        repo = self.sysroot.repo()
        out_pending,out_rollback = self.sysroot.query_deployments_for(self.osname)

        if out_rollback:
            rollback_checksum = self.deployment.get_csum()

            ret,metadata = repo.load_variant(OSTree.ObjectType.COMMIT,rollback_checksum)

            n_metadata = metadata[0]
            
            return n_metadata
        else:
            return ""
        
    def get_metadata(self,checksum):
        repo = self.sysroot.repo()
        ret,metadata = repo.load_variant(OSTree.ObjectType.COMMIT,checksum)
        return metadata[0]
