#!/usr/bin/python3

import os
import json
import logging
from gi.repository import Gio
from gettext import gettext as _
from SystemUpdater.Core.errors import *
from SystemUpdater.Core.enums import *

class UpdatesAvailable():
    """
    Represent the (potentially partial) results of an unattended-upgrades
    run
    """

    # 更新的缓存数据保存位置 
    UPDATE_AVAILABLE_DATA = "/var/cache/kylin-system-updater/update_available_data.json"

    def __init__(self,parent):
        self.parent = parent

        self.error_code = ''
        self.exit = None

        self.is_upgradable = False
        self.available_checksum = None
        self.available_refs = None
        self.available_metadata = None

        def cancelled():
            logging.info("Task has been cancelled...")
        self.cancellable = Gio.Cancellable.new()
        self.cancellable.connect(cancelled)

    def _output_resolver_pkgs(self,pkgs):
        OUTPUT_JSON = "/var/lib/kylin-system-updater/json/requires_upgrade_pkgs.json"
        try:
            output_upgrade = {}

            pkg_string = ''
            for pkg in pkgs:
                pkg_string = pkg_string + ' ' + str(pkg)

            output_upgrade.update({"packages":pkg_string})

            with open(OUTPUT_JSON, 'w', encoding='utf-8') as f:
                json.dump(output_upgrade, f, ensure_ascii=False, indent=4)

            logging.info("Generate Jsonfile(%s) to complete... ",OUTPUT_JSON)
            logging.info("Update Packages list to config file...")
        except Exception as exc:
            logging.error(exc)

    def _write_local(self):
        try:
            output_upgrade = {}
            output_upgrade.update({"steps_queue":self.steps_queue})
            output_upgrade.update({"_problem_resolver":self._problem_resolver})
            output_upgrade.update({"updating_data":self.updating_data})
            output_upgrade.update({"upgrade_singles":self.upgrade_singles})
            output_upgrade.update({"upgrade_groups":self.upgrade_groups})
            output_upgrade.update({"upgrade_steps":self.upgrade_steps})
            output_upgrade.update({"device_status":self.device_status})
            output_upgrade.update({"shutdown_install":self.shutdown_install})
            output_upgrade.update({"signal_trigger":self.signal_trigger})
            output_upgrade.update({"_available":self._available})

            #6 产生JSON文件
            with open(self.UPDATE_AVAILABLE_DATA, 'w', encoding='utf-8') as f:
                json.dump(output_upgrade, f, ensure_ascii=False, indent=4)
            logging.info("Write Upgrade data to local json(%s) in shutdown model...",self.UPDATE_AVAILABLE_DATA)
        except Exception as exc:
            logging.error(exc)
    def read_local(self):
        #读取组JSON文件
        try:
            with open(self.UPDATE_AVAILABLE_DATA,'r') as f:
                data = json.load(f)
                self.steps_queue = data["steps_queue"]
                self._problem_resolver = data["_problem_resolver"]
                self.updating_data = data["updating_data"]
                self.upgrade_singles = data["upgrade_singles"]
                self.upgrade_groups = data["upgrade_groups"]
                self.upgrade_steps = data["upgrade_steps"]
                self.device_status = data["device_status"]
                self.shutdown_install = data["shutdown_install"]
                self.signal_trigger = data["signal_trigger"]
                self._available = data["_available"]
            logging.info("Finished: reading upgrade data from the local file...")
        except Exception as exc:
            logging.error(exc)

    def _get_available(self):
        return self._available

    def _set_available(self, state):
        self._available = state
        self._write_local()

    available = property(_get_available, _set_available)
